"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DateTimeType = void 0;
const core_1 = require("@tangential/core");
const moment = require("moment");
const configurable_input_type_1 = require("../configurable-input-type");
const date_time_ival_1 = require("./date-time-ival");
const BROWSER_DATE_TIME_LOCAL_FORMAT = 'YYYY-MM-DDTHH:mm:ss';
const Model = {
    afterMils: null,
    beforeMils: null,
    defaultValue: null,
    defaultToNow: true
};
class DateTimeType extends configurable_input_type_1.ConfigurableInputType {
    constructor(config, key) {
        super(config || {}, key);
    }
    getInputTypeKey() {
        return DateTimeType.TYPE_NAME;
    }
    get uiValue() {
        return moment(this.defaultValue).format(BROWSER_DATE_TIME_LOCAL_FORMAT);
    }
    set uiValue(val) {
        this.defaultValue = moment(val, BROWSER_DATE_TIME_LOCAL_FORMAT).valueOf();
    }
    isNumeric() {
        return false;
    }
    createValue(cfg, key) {
        cfg = cfg || {};
        return new date_time_ival_1.DateTimeIval({
            value: cfg.value || this.getDefaultValue(),
            recordedInTimeZone: cfg.recordedInTimeZone || 'GMT'
        }, key || this.$key);
    }
    getDefaultValue() {
        return this.defaultToNow ? Date.now() : this.defaultValue;
    }
}
exports.DateTimeType = DateTimeType;
DateTimeType.$model = core_1.ObjectUtil.assignDeep({}, configurable_input_type_1.ConfigurableInputType.$model, Model);
DateTimeType.TYPE_NAME = 'DateTime';
configurable_input_type_1.ConfigurableInputType.register(DateTimeType);
//# sourceMappingURL=date-time-type.js.map