"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TextType = void 0;
const core_1 = require("@tangential/core");
const configurable_input_type_1 = require("../configurable-input-type");
const text_ival_1 = require("./text-ival");
/**
 * == Reporting
 * Text types can represent things like:
 *  * Quick notes, such as idea, or a Capture for 'I met a new person', and the persons name is the value.
 *  * Mood / Feeling
 *  * Name of a food eaten
 *  * Name of a place visited.
 *  * Name of a medication taken.
 *
 *
 * === Charts/Graphs
 * A text value is hard to plot in isolation. But consider the case of 'met a person'. In this case we could
 * plot time on the horizontal axis and number of people met per range. This would become a stacked bar chart?
 *
 * For something like mood, let's consider two cases:
 *   1) The capture is 'When' and 'Mood'. In this case we can have an arbitrary number of points in a day,
 *   and the user is probably going to want to correlate this value to time of day.
 *   - Go with a scatter plot, with days of the week on the X and hour of day on the Y, with the field as the point
 *     label.
 *   2) The capture is 'When', 'Feeling<text>', 'Weight<numeric>'.
 *
 */
const Model = {
    maxLength: 50,
    minLength: 0,
    defaultValue: null
};
class TextType extends configurable_input_type_1.ConfigurableInputType {
    constructor(config) {
        super(config || {});
    }
    getInputTypeKey() {
        return TextType.TYPE_NAME;
    }
    isNumeric() {
        return false;
    }
    createValue(cfg, key) {
        cfg = cfg || {};
        return new text_ival_1.TextIval({
            value: cfg.value || this.defaultValue
        }, key || this.$key);
    }
}
exports.TextType = TextType;
TextType.$model = core_1.ObjectUtil.assignDeep({}, configurable_input_type_1.ConfigurableInputType.$model, Model);
TextType.TYPE_NAME = 'Text';
configurable_input_type_1.ConfigurableInputType.register(TextType);
//# sourceMappingURL=text-type.js.map