"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InputRegistry = exports.InputSet = void 0;
const core_1 = require("@angular/core");
const core_2 = require("@tangential/core");
//noinspection ES6PreferShortImport
const checkbox_widget_config_1 = require("../widgets/checkbox/checkbox-widget-config");
//noinspection ES6PreferShortImport
const checkbox_widget_template_component_1 = require("../widgets/checkbox/checkbox-widget.template.component");
//noinspection ES6PreferShortImport
const date_time_input_config_1 = require("../widgets/date-time-input/date-time-input-config");
//noinspection ES6PreferShortImport
const date_time_template_component_1 = require("../widgets/date-time-input/date-time-template.component");
//noinspection ES6PreferShortImport
const duration_picker_config_1 = require("../widgets/duration-picker/duration-picker-config");
//noinspection ES6PreferShortImport
const duration_picker_template_component_1 = require("../widgets/duration-picker/duration-picker-template.component");
//noinspection ES6PreferShortImport
const icon_rating_widget_config_1 = require("../widgets/icon-rating-widget/icon-rating-widget-config");
//noinspection ES6PreferShortImport
const icon_rating_widget_template_component_1 = require("../widgets/icon-rating-widget/icon-rating-widget.template.component");
//noinspection ES6PreferShortImport
const number_input_config_1 = require("../widgets/number-input/number-input-config");
//noinspection ES6PreferShortImport
const number_template_component_1 = require("../widgets/number-input/number-template.component");
//noinspection ES6PreferShortImport
const number_slider_config_1 = require("../widgets/number-slider/number-slider-config");
//noinspection ES6PreferShortImport
const number_slider_template_component_1 = require("../widgets/number-slider/number-slider-template.component");
//noinspection ES6PreferShortImport
const number_spinner_config_1 = require("../widgets/number-spinner/number-spinner-config");
//noinspection ES6PreferShortImport
const number_spinner_template_component_1 = require("../widgets/number-spinner/number-spinner-template.component");
//noinspection ES6PreferShortImport
const slide_toggle_widget_config_1 = require("../widgets/slide-toggle/slide-toggle-widget-config");
//noinspection ES6PreferShortImport
const slide_toggle_widget_template_component_1 = require("../widgets/slide-toggle/slide-toggle-widget.template.component");
//noinspection ES6PreferShortImport
const text_input_config_1 = require("../widgets/text-input/text-input-config");
//noinspection ES6PreferShortImport
const text_template_component_1 = require("../widgets/text-input/text-template.component");
const input_view_mode_1 = require("./input-view-mode");
const i0 = require("@angular/core");
class InputSet {
    constructor(config, view) {
        this.inputCtor = config;
        this.view = view;
    }
    createInputConfig(data, key) {
        return new this.inputCtor(data || {}, key);
    }
}
exports.InputSet = InputSet;
class InputRegistry {
    constructor() {
        this.inputEntries = {};
        this.registerTypes();
    }
    registerTypes() {
        this.inputEntries[checkbox_widget_config_1.CheckboxWidgetConfig.INPUT_NAME] = new InputSet(checkbox_widget_config_1.CheckboxWidgetConfig, checkbox_widget_template_component_1.CheckboxWidgetTemplateComponent);
        this.inputEntries[slide_toggle_widget_config_1.SlideToggleConfig.INPUT_NAME] = new InputSet(slide_toggle_widget_config_1.SlideToggleConfig, slide_toggle_widget_template_component_1.SlideToggleWidgetTemplateComponent);
        this.inputEntries[number_input_config_1.NumberInputConfig.INPUT_NAME] = new InputSet(number_input_config_1.NumberInputConfig, number_template_component_1.NumberTemplateComponent);
        this.inputEntries[number_spinner_config_1.NumberSpinnerConfig.INPUT_NAME] = new InputSet(number_spinner_config_1.NumberSpinnerConfig, number_spinner_template_component_1.NumberSpinnerTemplateComponent);
        this.inputEntries[number_slider_config_1.NumberSliderConfig.INPUT_NAME] = new InputSet(number_slider_config_1.NumberSliderConfig, number_slider_template_component_1.NumberSliderTemplateComponent);
        this.inputEntries[text_input_config_1.TextInputConfig.INPUT_NAME] = new InputSet(text_input_config_1.TextInputConfig, text_template_component_1.TextTemplateComponent);
        this.inputEntries[date_time_input_config_1.DateTimeInputConfig.INPUT_NAME] = new InputSet(date_time_input_config_1.DateTimeInputConfig, date_time_template_component_1.DateTimeTemplateComponent);
        this.inputEntries[duration_picker_config_1.DurationPickerConfig.INPUT_NAME] = new InputSet(duration_picker_config_1.DurationPickerConfig, duration_picker_template_component_1.DurationPickerTemplateComponent);
        this.inputEntries[icon_rating_widget_config_1.IconRatingWidgetConfig.INPUT_NAME] = new InputSet(icon_rating_widget_config_1.IconRatingWidgetConfig, icon_rating_widget_template_component_1.IconRatingWidgetTemplateComponent);
    }
    allTemplates(mode) {
        return core_2.ObjectUtil.keys(this.inputEntries).map((inputName) => {
            return this.createTemplateForTypeKey(inputName, mode);
        });
    }
    getInputSet(inputName) {
        return this.inputEntries[inputName];
    }
    getComponentCtorFor(inputConfig, mode) {
        let result;
        const entry = this.inputEntries[inputConfig._inputName];
        result = entry.view;
        if (!result) {
            throw new Error(`Invalid mode '${mode}'.`);
        }
        return result;
    }
    createTemplateForTypeKey(inputName, mode) {
        const inputEntrySet = this.getInputSet(inputName);
        const inputConfig = inputEntrySet.createInputConfig();
        return {
            config: inputConfig,
            ival: inputConfig.typeConfig.createValue(),
            mode: mode
        };
    }
    createTemplateForType(inputConfig, mode, ival) {
        ival = ival || inputConfig.typeConfig.createValue({});
        mode = mode || input_view_mode_1.InputViewModes.EDIT;
        ival.$key = inputConfig.$key;
        return {
            config: inputConfig,
            ival: ival,
            mode: mode
        };
    }
    get inputNames() {
        return Object.keys(this.inputEntries);
    }
}
exports.InputRegistry = InputRegistry;
InputRegistry.ɵfac = function InputRegistry_Factory(t) { return new (t || InputRegistry)(); };
InputRegistry.ɵprov = /*@__PURE__*/ i0.ɵɵdefineInjectable({ token: InputRegistry, factory: InputRegistry.ɵfac });
(function () { (typeof ngDevMode === "undefined" || ngDevMode) && i0.ɵsetClassMetadata(InputRegistry, [{
        type: core_1.Injectable
    }], function () { return []; }, null); })();
//# sourceMappingURL=input-types-registry.js.map